class Game_Actor
  attr_reader :bio
  
  alias mp_bio_setup setup
  def setup(actor_id)
    mp_bio_setup(actor_id)
    # Create biography
    @bio = Game_Bio.new
    # Add name to biography
    @bio[:name] = @name + " "
    # Add class to biography
    @bio[:class] = $data_classes[@class_id].name
    # Initialize biography
    init_bio do |feature, data|
      @bio[feature] = data
    end
  end
  
  # Initialize bio data according to id
  def init_bio
    #---------------------------------------------------------------------------
    # Set each actor's bio using the following syntax
    #
    # case @actor_id
    # when <actor id>
    #   yield <feature1>, <data1>
    #   yield <feature2>, <data2>
    #   yield <feature3>, <data3>
    #   ...
    # end
    #
    # NOTES
    # The setting order will be preserved when displaying the bio
    # Strings are automatically broken into lines (change Window_Bio#SIZE_LINE
    # in Scene_Bio entry to get more or less characters per line)
    # Setting a feature twice overrides its content rather than add a duplicate
    # entry
    # In order to hide the content of some features, enter the following:
    #
    # $game_actors[<actor id>].bio.hide(<feature1>, <feature2>, <feature3>, ...)
    #
    # Then use the following to revert this effect:
    #
    # $game_actors[<actor id>].bio.reveal(<feature1>, <feature2>, <feature3>, ...)
    #---------------------------------------------------------------------------    
    case @actor_id
    when 1  # Aluxes
      yield :age, 18
      yield :gender, :male
      yield :race, :human
      yield :star_sign, :taurus
      yield :virtue, :careful
      yield :flaw, :stubborn
      yield :history, 
        "This is where Aluxes's background should be written. Of course there's no need to make it this long, but it's merely to demonstrate the script's ability to automatically break long descriptions into lines of appropriate size - and also the fact that the window can scroll up and down."
    when 2  # Basil
      yield :gender, :male
      yield :star_sign, :capricorn
      yield :history,
        "This bio demonstrates how the features' appearance order may be changed at will - likewise, all features need not be defined."
      yield :virtue, :patient
      yield :flaw, :loner
    when 3  # Cyrus
      yield :age, 23
      yield :gender, :male
      yield :race, :human
      yield :star_sign, :gemini
      yield :virtue, :loyal
      yield :flaw, :arrogant
      yield :history,
        "This bio demonstrates how entries can be modified - duplicate entries override each other rather than pile up."
      yield :age, 35
      yield :star_sign, :leo
    when 4  # Dorothy
      yield :age, 17
      yield :gender, :female
      yield :race, :human
      yield :star_sign, :scorpio
      yield :virtue, :sharp
      yield :flaw, :defiant
      yield :history,
        "She's a very secretive person, that's why little is known about her yet - even though everything's defined in the script."
      # This hides some of the actor's feature, use Game_Bio#reveal(*features) to undo
      @bio.hide(:age, :race, :star_sign)
    else  # Everyone else
      yield :age, 26
      yield :race, :none
      yield :star_sign, :none
      yield :history,
        "This bio demonstrates how default settings can be applied for actors without a bio."
    end
  end
end